@@ -17,8 +17,6 @@
 #' @family pdftools
 #' @aliases render
 #' @examples # Rendering should be supported on all platforms now
-#' if(poppler_config()$can_render){
-#'
 #' # convert few pages to png
 #' file.copy(file.path(Sys.getenv("R_DOC_DIR"), "NEWS.pdf"), "news.pdf")
 #' pdf_convert("news.pdf", pages = 1:3)
@@ -38,7 +36,10 @@
 #' # slightly more efficient
 #' bitmap_raw <- pdf_render_page("news.pdf", numeric = FALSE)
 #' webp::write_webp(bitmap_raw, "page.webp")
-#' }
+#'
+#' # Cleanup
+#' unlink(c('news.pdf', 'news_1.png', 'news_2.png', 'news_3.png',
+#'  'page.jpeg', 'page.png', 'page.webp'))
 pdf_render_page<- function(pdf, page = 1, dpi = 72, numeric = FALSE, antialias = TRUE, opw = "", upw = "") {
   antialiasing <- isTRUE(antialias) || isTRUE(antialias == "draw")
   text_antialiasing <- isTRUE(antialias) || isTRUE(antialias == "text")
@@ -73,9 +74,13 @@ pdf_convert <- function(pdf, format = "png", pages = NULL, filenames = NULL , dp
     pages <- seq_len(pdf_info(pdf, opw = opw, upw = upw)$pages)
   if(!is.numeric(pages) || !length(pages))
     stop("Argument 'pages' must be a one-indexed vector of page numbers")
-  if(!length(filenames)){
+  if(length(filenames) < 2){
     input <- sub(".pdf", "", basename(pdf), fixed = TRUE)
-    filenames <- sprintf("%s_%d.%s", input, pages, format)
+    filenames <- if (length(filenames)) {
+      sprintf(filenames, pages, format)
+    } else {
+      sprintf("%s_%d.%s", input, pages, format)
+    }
   }
   if(length(filenames) != length(pages))
     stop("Length of 'filenames' must be one or equal to 'pages'")
